// set the dimensions and margins of the graph
const width = 800;
const height = 500;

// append the svg object to the body of the page
const svg = d3
  .select('#my_dataviz')
  .append('svg')
  .attr('width', width / 2)
  .attr('height', height);

const svg2 = d3
  .select('#my_dataviz')
  .append('svg')
  .attr('width', width / 2)
  .attr('height', height);

function render(mapData, countryData) {
  var projection = d3
    .geoEqualEarth()
    .fitSize([width / 2, height], mapData);

  var path = d3.geoPath(projection);

  const colorAttr = 'Birth Rate';
  const xDataRange = d3.extent(
    d3.map(countryData.values(), (v) => +v[colorAttr]),
  );

  console.log(countryData.values());
  console.log(xDataRange);

  var colorScale = d3
    .scaleLinear()
    .domain(xDataRange)
    .range(['blue', 'red']);

  svg2
    .append('g')
    .selectAll('path')
    .data(mapData.features)
    .join('path')
    .attr('d', path)
    .attr('fill', (d) => {
      if (countryData.has(d.properties.name)) {
        return colorScale(
          countryData.get(d.properties.name)[colorAttr],
        );
      } else {
        return 'grey';
      }
    });
}

//Read the data
const mapUrl =
  'https://raw.githubusercontent.com/holtzy/D3-graph-gallery/master/DATA/world.geojson';
const countryStatsUrl =
  'https://raw.githubusercontent.com/bepnye/CP341/main/world-data-2023.csv';
const continentUrl =
  'https://raw.githubusercontent.com/samayo/country-json/master/src/country-by-continent.json';

Promise.all([
  d3.json(mapUrl),
  d3.csv(countryStatsUrl),
  d3.json(continentUrl),
]).then(([mapData, csvData, continentData]) => {
  console.log(mapData);
  console.log(csvData);
  console.log(continentData);

  var countryData = new Map();
  csvData.forEach((row) => {
    row.Population = row.Population.replaceAll(',', '');
    row['Co2-Emissions'] = row['Co2-Emissions'].replaceAll(
      ',',
      '',
    );
    countryData.set(row.Country, row);
  });

  console.log(countryData);
  render(mapData, countryData);
});
